#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sphinx_view']

package_data = \
{'': ['*']}

setup(name='django-sphinx-view',
      version='21.1a1',
      description='Serve your Sphinx docs with Django.',
      author='Carlton Gibson',
      author_email='carlton.gibson@noumenal.es',
      url='https://noumenal.es/django-sphinx-view/',
      packages=packages,
      package_data=package_data,
     )
